@@ -247,7 +247,7 @@ impl PanelState for FilesystemState {
         if con.show_selection_mark {
             wc_fs += 1;
         }
-        let w_dsk = 3;
+        let w_dsk = 5; // max width of a lfs-core disk type
         let w_type = mounts.iter()
             .map(|m| m.info.fs_type.chars().count())
             .max().unwrap_or(0)
@@ -304,7 +304,7 @@ impl PanelState for FilesystemState {
         cw.queue_g_string(&styles.default, format!("{:width$}", "filesystem", width = wc_fs))?;
         cw.queue_char(border_style, '│')?;
         if e_dsk {
-            cw.queue_g_string(&styles.default, "dsk".to_string())?;
+            cw.queue_g_string(&styles.default, "disk ".to_string())?;
             cw.queue_char(border_style, '│')?;
         }
         if e_type {
@@ -373,10 +373,10 @@ impl PanelState for FilesystemState {
                             txt_style,
                             match_style,
                         );
-                        matched_string.fill(3, Alignment::Left);
+                        matched_string.fill(5, Alignment::Center);
                         matched_string.queue_on(&mut cw)?;
                     } else {
-                        cw.queue_g_string(txt_style, "   ".to_string())?;
+                        cw.queue_g_string(txt_style, "     ".to_string())?;
                     }
                     cw.queue_char(border_style, '│')?;
                 }
@@ -395,13 +395,16 @@ impl PanelState for FilesystemState {
                 }
                 // size, used, free
                 if let Some(stats) = mount.stats.as_ref().filter(|s| s.size() > 0) {
+                    let share_color = super::share_color(stats.use_share());
                     // size
                     cw.queue_g_string(txt_style, format!("{:>4}", file_size::fit_4(mount.size())))?;
                     cw.queue_char(border_style, '│')?;
                     // used
                     if e_use {
                         cw.queue_g_string(txt_style, format!("{:>4}", file_size::fit_4(stats.used())))?;
-                        let share_color = super::share_color(stats.use_share());
+                        if e_use_share {
+                            cw.queue_g_string(txt_style, format!("{:>3.0}%", 100.0*stats.use_share()))?;
+                        }
                         if e_use_bar {
                             cw.queue_char(txt_style, ' ')?;
                             let pb = ProgressBar::new(stats.use_share() as f32, w_use_bar);
@@ -409,15 +412,12 @@ impl PanelState for FilesystemState {
                             bar_style.set_bg(share_color);
                             cw.queue_g_string(&bar_style, format!("{:<width$}", pb, width=w_use_bar))?;
                         }
-                        if e_use_share {
-                            let mut share_style = txt_style.clone();
-                            share_style.set_fg(share_color);
-                            cw.queue_g_string(&share_style, format!("{:>3.0}%", 100.0*stats.use_share()))?;
-                        }
                         cw.queue_char(border_style, '│')?;
                     }
                     // free
-                    cw.queue_g_string(txt_style, format!("{:>4}", file_size::fit_4(stats.available())))?;
+                    let mut share_style = txt_style.clone();
+                    share_style.set_fg(share_color);
+                    cw.queue_g_string(&share_style, format!("{:>4}", file_size::fit_4(stats.available())))?;
                     cw.queue_char(border_style, '│')?;
                 } else {
                     // size
